@@ -9,8 +9,9 @@ import subprocess
 
 # cli_commands for the buildpan 
 
-from cli_commands import init
-from cli_commands import version
+from c_commands import init
+from c_commands import version
+
 @click.group(help="CLI tool to manage CI- CD of projects")
 def buildpan():
     pass
@@ -18,5 +19,6 @@ def buildpan():
 
 buildpan.add_command(init.init)
 buildpan.add_command(version.version)
+
 if __name__ == '__main__':
     buildpan()
\ No newline at end of file
